@@ -16,12 +16,12 @@ import demix_lib.demix_url_handler as dh
 # CONSTANTS
 # ---------------------------------------------------------------------------------------------------------------------
 
-def download_layer(tile_name, dem, layer):
+def download_layer(demix_tile_name, dem, layer):
     """
     Allow you to download a specific layer as a geotiff
-    :param tile_name: the demix tile name
+    :param demix_tile_name: the demix tile name
     :param dem: the dem from which you want to get a layer
     :param layer: the layer name
     :return: the wanted layer
     """
-    return dh.request_pixels(tile_name=tile_name, dem=dem, layer=layer)
+    return dh.request_pixels(tile_name=demix_tile_name, dem=dem, layer=layer)
